@@ -364,7 +364,7 @@ where
     }
 }
 
-#[derive(Serialize, Deserialize, Debug)]
+#[derive(Serialize, Deserialize, Debug, Clone)]
 pub struct Tokenizer(
     TokenizerImpl<
         ModelWrapper,
